@@ -15,6 +15,10 @@ limitations under the License.
 """
 
 HTTPS_ONLY = 'EGGPLANT_HTTPS_ONLY'
+DEPLOYED = 'EGGPLANT_DEPLOYED'
+
 PERMISSION_DICT = 'EGGPLANT_PERMISSION_DICT'
 
-SECRET_SALT = 'EGGPLANT_SECRET_SALT' # required
\ No newline at end of file
+SIGNATURE_KEY_CLASS = 'EGGPLANT_SIGNATURE_KEY_CLASS'
+AJAX_SIGNATURE_KEY_CLASS = 'EGGPLANT_AJAX_SIGNATURE_KEY_CLASS'
+USER_TOKEN_CLASS = 'EGGPLANT_SIGNATURE_KEY_CLASS'
\ No newline at end of file
